==> haskell-http-client-0.7.19-54-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.19
visibility:           public
id:                   http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
key:                  http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  7e01312e54f075b1b73a601745e3392c
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
depends:
    array-0.5.6.0 async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 deepseq-1.4.8.1
    exceptions-0.10.7 filepath-1.4.300.1 ghc-prim-0.10.0
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    iproute-1.7.15-G8PIBt0bMmIHonL1qb456T
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj stm-2.5.1.0
    streaming-commons-0.2.3.1-J8SxFARI4BPDYt3Np6OVv5 text-2.0.2
    time-1.12.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.7.19-55-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.19
visibility:           public
id:                   http-client-0.7.19-HYRPxJ1velFCbteX9ut4f6
key:                  http-client-0.7.19-HYRPxJ1velFCbteX9ut4f6
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  8e3ee57a1cef634fbac2799cfe8aecb1
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.19-HYRPxJ1velFCbteX9ut4f6
depends:
    array-0.5.6.0 async-2.2.5-BOONqED6PxbDsY8XxcvMc4 base-4.18.2.1
    base64-bytestring-1.2.1.0-LrCtfbXf96jILPXKH7KAXZ
    blaze-builder-0.4.4.1-Hto81bisFYkHXSmpZG8kx7 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8PStX6cixKCLkUJoPuARL containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 deepseq-1.4.8.1
    exceptions-0.10.7 filepath-1.4.300.1 ghc-prim-0.10.0
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    iproute-1.7.15-3GkfBOWcvcU41ReIxtPoLT
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    network-3.1.4.0-xB4epdb1XO3ZKzAxljM4X
    network-uri-2.6.4.2-1aRZPUfkmMD8JwUJF5GqMA
    random-1.2.1.3-6l1YOhgkyj83HD6td8a68Q stm-2.5.1.0
    streaming-commons-0.2.3.1-p6JZxPGlgm2ju1b9E77qr text-2.0.2
    time-1.12.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
